@@ -1,4 +1,5 @@
 import json
+from typing import List, Optional, Union
 
 
 class PipelineWorkflowMixin(object):
@@ -307,7 +308,12 @@ class PipelineWorkflowMixin(object):
         return self._process_response(res)
 
     def rerun_pipeline_workflow(
-        self, project_id, workflow_id, from_index=False, step_ids=None
+        self,
+        project_id: str,
+        workflow_id: str,
+        from_index: bool = False,
+        step_ids: Optional[Union[str, List[str]]] = None,
+        run_linked_steps: Optional[bool] = None,
     ):
         """Rerun a pipeline workflow using the data of its configured data sources.
 
@@ -315,6 +321,14 @@ class PipelineWorkflowMixin(object):
         :param workflow_id: the Id of the pipeline workflow to rerun.
         :param from_index: if True then this flag indicates that rerun will use the
             indexed Squirro items as input to the workflow for ingestion.
+        :param step_ids: the IDs of one or more steps of the provided pipeline workflow
+            that the rerun from index will be executed on. The rest of the steps in the
+            workflow will be omitted.
+        :param run_linked_steps: a flag which indicates whether to rerun from index the
+            linked steps of the step provided by the `step_ids`. It has an effect only
+            when the `step_ids` parameter is provided. If multiple step IDs are included
+            in the provided `step_ids`, then only the first step in the list, along with
+            its set of linked steps, will rerun from index.
         """
         headers = {"Content-Type": "application/json"}
 
@@ -322,7 +336,9 @@ class PipelineWorkflowMixin(object):
 
         data = {}
         if step_ids:
-            data["step_ids"] = step_ids
+            data["step_ids"] = step_ids if isinstance(step_ids, list) else [step_ids]
+        if run_linked_steps:
+            data["run_linked_steps"] = run_linked_steps
 
         url = (
             "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
