@@ -1,15 +1,16 @@
 import json
+from typing import Optional
 
-from squirro_client.util import deprecation
+from squirro_client.util import _clean_params, deprecation
 
 
 class SourcesMixin(object):
     def get_sources(
         self,
-        project_id,
-        include_config=None,
-        include_run_stats=None,
-        include_pipeline_backlog=None,
+        project_id: str,
+        include_config: Optional[bool] = None,
+        include_run_stats: Optional[bool] = None,
+        include_pipeline_backlog: Optional[bool] = None,
     ):
         """Get all sources for the provided project.
 
@@ -73,24 +74,124 @@ class SourcesMixin(object):
               }
             ]
         """
-
-        url = "%(ep)s/%(version)s/%(tenant)s" "/projects/%(project_id)s" "/sources"
-        url = url % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
+        url = f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}/sources"
+        params = {
+            "include_config": include_config,
+            "include_run_stats": include_run_stats,
+            "include_pipeline_backlog": include_pipeline_backlog,
         }
 
-        params = {}
-        if include_config:
-            params["include_config"] = include_config
-        if include_run_stats:
-            params["include_run_stats"] = include_run_stats
-        if include_pipeline_backlog:
-            params["include_pipeline_backlog"] = include_pipeline_backlog
+        res = self._perform_request("get", url, params=_clean_params(params))
+        return self._process_response(res)
 
-        res = self._perform_request("get", url, params=params)
+    def get_sources_v1(
+        self,
+        project_id: str,
+        search: Optional[str] = None,
+        status: Optional[str] = None,
+        plugin_name: Optional[str] = None,
+        include: Optional[str] = None,
+        counts_agg: Optional[str] = None,
+        start: int = 0,
+        count: int = -1,
+    ):
+        """Get sources for the provided project.
+
+        :param project_id: Project identifier.
+        :param search: filter by part of Source name
+        :param status: filter by Source status
+        :param plugin_name: filter by Source plugin_name
+        :param include: comma seperated list of additional Source fields.
+            config - Source config
+            run_stats - Source run stats
+            pipeline_backlog - Source backlog information from ingester
+            items_indexed - number of indexed items from Source
+        :param counts_agg: whether or not to include Sources field value aggregations.
+            Specified as comma seperated string of aggregated fields.
+            Possible fields: `status,plugin_name`.
+        :param start: Integer. Used for pagination of objects. If set, the
+            objects starting with offset `start` are returned.
+        :param count: Integer. Used for pagination of objects. If set, `count`
+            number of objects are returned. To return all objects, set
+            to -1.
+
+        :returns: A paginated list of sources.
+
+        Example::
+
+            >>> client.get_sources_v1(
+            ...    project_id='Vlg5Z1hOShm0eYmjtsqSqg',
+            ...    include="config,run_stats,pipeline_backlog,items_indexed",
+            ...    counts_agg="status,plugin_name",
+            ...    count=1,
+            ... )
+
+            {
+              "count": 1,
+              "sources": [
+                {
+                  "items_fetched_total": 2,
+                  "last_error": "",
+                  "last_check_at": "2019-01-23T10:23:23",
+                  "last_items_at": "2019-01-23T10:23:23",
+                  "paused": false,
+                  "error_count": 0,
+                  "id": "pqTn4vBZRdS5hYw0TBt0pQ",
+                  "total_error_count": 0,
+                  "project_id": "Vlg5Z1hOShm0eYmjtsqSqg",
+                  "config": {
+                    "dataloader_plugin_options": {
+                      "source_file": "path:/tmp/test.csv"
+                    },
+                    "dataloader_options": {
+                      "map_title": "title",
+                      "project_id": "Vlg5Z1hOShm0eYmjtsqSqg",
+                      "plugin_name": "csv_plugin"
+                    }
+                  },
+                  "status": "complete",
+                  "total_runs": 1,
+                  "pipeline_workflow_id": "S0fVQ-K0TmS1UgT0msZRBA",
+                  "last_error_at": null,
+                  "last_update_at": "2019-01-23T10:23:23",
+                  "last_success_at": "2019-01-23T10:23:23",
+                  "items_fetched_last_run": 2,
+                  "tenant": "squirro",
+                  "next_run_time_at": "2019-01-23T10:52:51",
+                  "name": "test source",
+                  "scheduling_options": {
+                    "repeat": "30m",
+                    "schedule": true
+                  },
+                  "created_at": "2019-01-23T10:23:23",
+                  "modified_at": "2019-01-23T10:23:23",
+                  "processed": true,
+                  "pipeline_backlog": 10,
+                  "items_indexed": 100
+                }
+              ],
+              "counts_agg": {
+                "plugin_name": {"values": [{"key": "csv_plugin", "value": 3}]},
+                "status": {"values": [{"key": "queued", "value": 2}, {"key": "running", "value": 0}, {"key": "errored", "value": 0}, {"key": "complete", "value": 1}]}
+              },
+              "total": 3,
+              "next_params": {
+                "count": 1,
+                "start": 1
+              }
+            }
+        """
+        url = f"{self.topic_api_url}/v1/{self.tenant}/projects/{project_id}/sources"
+        params = {
+            "search": search,
+            "include": include,
+            "status": status,
+            "plugin_name": plugin_name,
+            "counts_agg": counts_agg,
+            "start": start,
+            "count": count,
+        }
+        res = self._perform_request("get", url, params=_clean_params(params))
         return self._process_response(res)
 
     def get_source(
